Repository.mk                                                       |    6 -
 RepositoryExternal.mk                                               |   10 -
 bin/check-elf-dynamic-objects                                       |    4 
 compilerplugins/clang/unusedfields.only-used-in-constructor.results |    8 -
 compilerplugins/clang/unusedfields.untouched.results                |    4 
 config_host.mk.in                                                   |    2 
 config_host/config_vclplug.h.in                                     |    2 
 configure.ac                                                        |   58 
+++++-----
 cui/source/options/optgdlg.cxx                                      |   10 -
 distro-configs/Jenkins/LibreOfficeLinuxUpdater.conf                 |    2 
 distro-configs/Jenkins/Linux_dev_master.conf                        |    2 
 distro-configs/Jenkins/Linux_rel_master.conf                        |    2 
 distro-configs/Jenkins/linux_clang_dbgutil_64                       |    2 
 distro-configs/Jenkins/linux_gcc_release_64                         |    2 
 distro-configs/LibreOfficeCoverity.conf                             |    2 
 distro-configs/LibreOfficeLinux.conf                                |    2 
 distro-configs/LibreOfficeOnline.conf                               |    2 
 distro-configs/LibreOfficeOpenBSD.conf                              |    2 
 distro-configs/LibreOfficeiOS.conf                                  |    2 
 distro-configs/LibreOfficeiOS_Sim.conf                              |    2 
 include/sal/log-areas.dox                                           |    2 
 postprocess/Rdb_services.mk                                         |    4 
 scp2/InstallScript_setup_osl.mk                                     |    2 
 scp2/Module_scp2.mk                                                 |    2 
 shell/Library_kf5be.mk                                              |   20 +--
 shell/Module_shell.mk                                               |    4 
 shell/source/backends/desktopbe/desktopbackend.cxx                  |    8 -
 shell/source/backends/kf5be/kf5access.cxx                           |    4 
 shell/source/backends/kf5be/kf5access.hxx                           |    6 -
 shell/source/backends/kf5be/kf5backend.cxx                          |   14 +-
 shell/source/backends/kf5be/kf5be1.component                        |    6 -
 svtools/source/uno/fpicker.cxx                                      |    8 -
 vcl/CustomTarget_kf5_moc.mk                                         |   12 +-
 vcl/Executable_lo_kde5filepicker.mk                                 |    2 
 vcl/Library_vcl.mk                                                  |    2 
 vcl/Library_vclplug_kf5.mk                                          |   38 
+++---
 vcl/Module_vcl.mk                                                   |   12 +-
 vcl/README                                                          |    4 
 vcl/inc/unx/desktops.hxx                                            |    2 
 vcl/inc/unx/gendata.hxx                                             |    2 
 vcl/inc/vclpluginapi.h                                              |    6 -
 vcl/qa/cppunit/app/test_IconThemeSelector.cxx                       |    4 
 vcl/qt5/Qt5Frame.cxx                                                |    4 
 vcl/source/app/IconThemeSelector.cxx                                |    2 
 vcl/source/app/salplug.cxx                                          |   18 +--
 vcl/unx/generic/desktopdetect/desktopdetector.cxx                   |   21 +--
 vcl/unx/gtk3_kde5/kde5_filepicker.cxx                               |    4 
 vcl/unx/kf5/KF5FilePicker.cxx                                       |   44 
+++----
 vcl/unx/kf5/KF5FilePicker.hxx                                       |    6 -
 vcl/unx/kf5/KF5SalFrame.cxx                                         |   26 ++--
 vcl/unx/kf5/KF5SalFrame.hxx                                         |    6 -
 vcl/unx/kf5/KF5SalInstance.cxx                                      |   32 
++---
 vcl/unx/kf5/KF5SalInstance.hxx                                      |    4 
 53 files changed, 224 insertions(+), 233 deletions(-)

New commits:
commit d3c6ac6d0f23df56644008ccb6aa2c8fa37ab1b5
Author:     Jan-Marek Glogowski <glo...@fbihome.de>
AuthorDate: Tue Jul 9 15:28:29 2019 +0000
Commit:     Jan-Marek Glogowski <glo...@fbihome.de>
CommitDate: Sun Jul 21 23:22:46 2019 +0200

    tdf#125922 rename kde5 to kf5 + plasma5
    
    Just as the gtk3 plugin isn't named GNOME, rename kde5 to kf5, as
    it is based on the KDE frameworks 5 libraries.
    
    This also includes:
    * a convenience alias to load the kf5 VCL plugin in case someone
      requests the kde5 plugin.
    * keep convenience kde5 configure switch, but warn about it
    * rename detected desktop from kde5 to plasma5
    
    Change-Id: I6764a05b81a5edbf284484c234fee2649aacf735
    Reviewed-on: https://gerrit.libreoffice.org/75313
    Tested-by: Jenkins
    Reviewed-by: Jan-Marek Glogowski <glo...@fbihome.de>

diff --git a/Repository.mk b/Repository.mk
index 5717370c3be3..d292bd461201 100644
--- a/Repository.mk
+++ b/Repository.mk
@@ -298,9 +298,9 @@ $(eval $(call 
gb_Helper_register_libraries_for_install,OOOLIBS,gnome, \
 ))
 
 $(eval $(call gb_Helper_register_libraries_for_install,OOOLIBS,kde, \
-       $(if $(ENABLE_KDE5),kde5be1) \
+       $(if $(ENABLE_KF5),kf5be1) \
        $(if $(USING_X11), \
-        $(if $(ENABLE_KDE5),vclplug_kde5) \
+        $(if $(ENABLE_KF5),vclplug_kf5) \
         $(if $(ENABLE_QT5),vclplug_qt5) \
         $(if $(ENABLE_GTK3_KDE5),vclplug_gtk3_kde5) \
        ) \
@@ -314,7 +314,7 @@ endif
 ifeq ($(OS),HAIKU)
 $(eval $(call gb_Helper_register_libraries_for_install,OOOLIBS,haiku, \
     $(if $(ENABLE_QT5),vclplug_qt5) \
-    $(if $(ENABLE_KDE5),vclplug_kde5) \
+    $(if $(ENABLE_KF5),vclplug_kf5) \
 ))
 endif
 
diff --git a/RepositoryExternal.mk b/RepositoryExternal.mk
index 730a3408a240..a66077d3bcbb 100644
--- a/RepositoryExternal.mk
+++ b/RepositoryExternal.mk
@@ -3076,9 +3076,9 @@ endef
 
 endif # SYSTEM_POSTGRESQL
 
-ifeq ($(ENABLE_KDE5),TRUE)
+ifeq ($(ENABLE_KF5),TRUE)
 
-define gb_LinkTarget__use_kde5
+define gb_LinkTarget__use_kf5
 $(call gb_LinkTarget_set_include,$(1),\
        $(subst -isystem/,-isystem /,$(filter -I% -isystem%,$(subst -isystem 
/,-isystem/,$(KF5_CFLAGS)))) \
        $$(INCLUDE) \
@@ -3094,13 +3094,13 @@ $(call gb_LinkTarget_add_libs,$(1),\
 
 endef
 
-else # !ENABLE_KDE5
+else # !ENABLE_KF5
 
-define gb_LinkTarget__use_kde5
+define gb_LinkTarget__use_kf5
 
 endef
 
-endif # ENABLE_KDE5
+endif # ENABLE_KF5
 
 
 
diff --git a/bin/check-elf-dynamic-objects b/bin/check-elf-dynamic-objects
index e1dec4b4f743..f2973c8b8ae0 100755
--- a/bin/check-elf-dynamic-objects
+++ b/bin/check-elf-dynamic-objects
@@ -121,8 +121,8 @@ local file="$1"
         */libavmediagst.so)
             whitelist="${whitelist} ${gtk3whitelist} ${gstreamerwhitelist}"
         ;;
-        */libvclplug_kde5lo.so|*/libkde5be1lo.so)
-            if [ "$ENABLE_KDE5" = TRUE ]; then
+        */libvclplug_kf5lo.so|*/libkf5be1lo.so)
+            if [ "$ENABLE_KF5" = TRUE ]; then
                 whitelist="${whitelist} ${qt5whitelist} ${kf5whitelist}"
             fi
         ;;
diff --git 
a/compilerplugins/clang/unusedfields.only-used-in-constructor.results 
b/compilerplugins/clang/unusedfields.only-used-in-constructor.results
index 8229f7f54cc2..db4b5e7efed6 100644
--- a/compilerplugins/clang/unusedfields.only-used-in-constructor.results
+++ b/compilerplugins/clang/unusedfields.only-used-in-constructor.results
@@ -840,10 +840,10 @@ vcl/unx/gtk/gloactiongroup.cxx:30
     GLOAction parent_instance GObject
 vcl/unx/gtk/glomenu.cxx:20
     GLOMenu parent_instance const GMenuModel
-vcl/unx/kde5/KDE5FilePicker.hxx:32
-    KDE5FilePicker _layout class QGridLayout *
-vcl/unx/kde5/KDE5FilePicker.hxx:34
-    KDE5FilePicker allowRemoteUrls _Bool
+vcl/unx/kf5/KF5FilePicker.hxx:32
+    KF5FilePicker _layout class QGridLayout *
+vcl/unx/kf5/KF5FilePicker.hxx:34
+    KF5FilePicker allowRemoteUrls _Bool
 writerfilter/source/dmapper/PropertyMap.hxx:198
     writerfilter::dmapper::SectionPropertyMap m_nDebugSectionNumber sal_Int32
 xmloff/source/text/XMLTextListBlockContext.hxx:35
diff --git a/compilerplugins/clang/unusedfields.untouched.results 
b/compilerplugins/clang/unusedfields.untouched.results
index 1f7b11f268f3..d7092855f60b 100644
--- a/compilerplugins/clang/unusedfields.untouched.results
+++ b/compilerplugins/clang/unusedfields.untouched.results
@@ -762,8 +762,8 @@ vcl/unx/gtk3/gtk3gtkinst.cxx:3532
     CrippledViewport viewport GtkViewport
 vcl/unx/gtk/a11y/atkhypertext.cxx:29
     HyperLink atk_hyper_link const AtkHyperlink
-vcl/unx/kde5/KDE5FilePicker.hxx:34
-    KDE5FilePicker allowRemoteUrls _Bool
+vcl/unx/kf5/KF5FilePicker.hxx:34
+    KF5FilePicker allowRemoteUrls _Bool
 writerfilter/source/ooxml/OOXMLStreamImpl.hxx:43
     writerfilter::ooxml::OOXMLStreamImpl mxFastParser 
css::uno::Reference<css::xml::sax::XFastParser>
 writerperfect/inc/WPFTEncodingDialog.hxx:37
diff --git a/config_host.mk.in b/config_host.mk.in
index 28d3ae3d2626..8db0d6ddd779 100644
--- a/config_host.mk.in
+++ b/config_host.mk.in
@@ -167,7 +167,7 @@ export ENABLE_PDFIMPORT=@ENABLE_PDFIMPORT@
 export ENABLE_PDFIUM=@ENABLE_PDFIUM@
 export ENABLE_POPPLER=@ENABLE_POPPLER@
 export ENABLE_QT5=@ENABLE_QT5@
-export ENABLE_KDE5=@ENABLE_KDE5@
+export ENABLE_KF5=@ENABLE_KF5@
 export ENABLE_GTK3_KDE5=@ENABLE_GTK3_KDE5@
 export ENABLE_RANDR=@ENABLE_RANDR@
 export ENABLE_RELEASE_BUILD=@ENABLE_RELEASE_BUILD@
diff --git a/config_host/config_vclplug.h.in b/config_host/config_vclplug.h.in
index 28b71d47a70a..694334dd4bf3 100644
--- a/config_host/config_vclplug.h.in
+++ b/config_host/config_vclplug.h.in
@@ -10,7 +10,7 @@ Settings about which desktops have support enabled.
 #define ENABLE_GTK 0
 #define ENABLE_GTK3 0
 #define ENABLE_GTK3_KDE5 0
-#define ENABLE_KDE5 0
+#define ENABLE_KF5 0
 #define ENABLE_QT5 0
 
 #define ENABLE_GSTREAMER_1_0 0
diff --git a/configure.ac b/configure.ac
index 2ef45d1cdd7c..0358692fc1d6 100644
--- a/configure.ac
+++ b/configure.ac
@@ -616,7 +616,7 @@ solaris*)
 linux-gnu*|k*bsd*-gnu*)
     test_gtk=yes
     build_gstreamer_1_0=yes
-    test_kde5=yes
+    test_kf5=yes
     test_gtk3_kde5=yes
     test_gdb_index=yes
     test_split_debug=yes
@@ -710,7 +710,7 @@ darwin*) # macOS or iOS
 freebsd*)
     test_gtk=yes
     build_gstreamer_1_0=yes
-    test_kde5=yes
+    test_kf5=yes
     test_gtk3_kde5=yes
     test_freetype=yes
     AC_MSG_CHECKING([the FreeBSD operating system release])
@@ -738,7 +738,7 @@ freebsd*)
 *netbsd*)
     test_gtk=yes
     build_gstreamer_1_0=yes
-    test_kde5=yes
+    test_kf5=yes
     test_gtk3_kde5=yes
     test_freetype=yes
     PTHREAD_LIBS="-pthread -lpthread"
@@ -763,7 +763,7 @@ openbsd*)
 dragonfly*)
     test_gtk=yes
     build_gstreamer_1_0=yes
-    test_kde5=yes
+    test_kf5=yes
     test_gtk3_kde5=yes
     test_freetype=yes
     PTHREAD_LIBS="-pthread"
@@ -785,7 +785,7 @@ linux-android*)
     test_fontconfig=no
     test_freetype=no
     test_gtk=no
-    test_kde5=no
+    test_kf5=no
     test_gtk3_kde5=no
     test_randr=no
     test_xrender=no
@@ -1271,15 +1271,20 @@ AC_ARG_ENABLE(qt5,
          available.]),
 ,)
 
-AC_ARG_ENABLE(kde5,
-    AS_HELP_STRING([--enable-kde5],
+AC_ARG_ENABLE(kf5,
+    AS_HELP_STRING([--enable-kf5],
         [Determines whether to use Qt5/KF5 vclplug on platforms where Qt5 and
          KF5 are available.]),
 ,)
 
+AC_ARG_ENABLE(kde5,
+    AS_HELP_STRING([--enable-kde5],
+        [Compatibility switch for the kde5 => kf5 rename. Use --enable-kf5!])
+,)
+
 AC_ARG_ENABLE(gtk3_kde5,
     AS_HELP_STRING([--enable-gtk3-kde5],
-        [Determines whether to use Gtk3 vclplug with KDE file dialogs on
+        [Determines whether to use Gtk3 vclplug with KF5 file dialogs on
          platforms where Gtk3, Qt5 and Plasma is available.]),
 ,)
 
@@ -4911,7 +4916,7 @@ if test "$USING_X11" != TRUE; then
     test_dbus=no
     test_gtk=no
     build_gstreamer_1_0=no
-    test_kde5=no
+    test_kf5=no
     test_qt5=no
     test_gtk3_kde5=no
     enable_cairo_canvas=no
@@ -4919,16 +4924,22 @@ fi
 
 if test "$OS" = "HAIKU"; then
     enable_cairo_canvas=yes
-    test_kde5=yes
+    test_kf5=yes
 fi
 
-if test "$test_kde5" = "yes"; then
+if test "x$enable_kde5" = "xyes"; then
+    AC_MSG_WARN([The kde5 VCL plugin was renamed to kf5. Please update your 
configuration to use --enable-kf5, as --enable-kde5 will be removed after the 
next major release!])
+    add_warning "The kde5 VCL plugin was renamed to kf5. Please update your 
configuration to use --enable-kf5, as --enable-kde5 will be removed after the 
next major release!"
+    test_kf5=yes
+fi
+
+if test "$test_kf5" = "yes"; then
     test_qt5=yes
 fi
 
-if test "$test_kde5" = "yes" -a  "$enable_kde5" = "yes"; then
+if test "$test_kf5" = "yes"; then
     if test "$enable_qt5" = "no"; then
-        AC_MSG_ERROR([KDE5 support depends on QT5, so it conflicts with 
--disable-qt5])
+        AC_MSG_ERROR([KF5 support depends on QT5, so it conflicts with 
--disable-qt5])
     else
         enable_qt5=yes
     fi
@@ -10461,13 +10472,13 @@ if test "x$enable_qt5" = "xyes"; then
 fi
 AC_SUBST(ENABLE_QT5)
 
-ENABLE_KDE5=""
-if test "x$enable_kde5" = "xyes"; then
-    ENABLE_KDE5="TRUE"
-    AC_DEFINE(ENABLE_KDE5)
-    R="$R kde5"
+ENABLE_KF5=""
+if test "x$enable_kf5" = "xyes"; then
+    ENABLE_KF5="TRUE"
+    AC_DEFINE(ENABLE_KF5)
+    R="$R kf5"
 fi
-AC_SUBST(ENABLE_KDE5)
+AC_SUBST(ENABLE_KF5)
 
 ENABLE_GTK3_KDE5=""
 if test "x$enable_gtk3_kde5" = "xyes"; then
@@ -11246,7 +11257,7 @@ AC_SUBST(ENABLE_SCRIPTING_JAVASCRIPT)
 AC_SUBST(SYSTEM_RHINO)
 AC_SUBST(RHINO_JAR)
 
-# This is only used in Qt5/KDE5 checks to determine if /usr/lib64
+# This is only used in Qt5/KF5 checks to determine if /usr/lib64
 # paths should be added to library search path. So lets put all 64-bit
 # platforms there.
 supports_multilib=
@@ -11271,7 +11282,7 @@ MOC5="moc"
 QT5_GOBJECT_CFLAGS=""
 QT5_GOBJECT_LIBS=""
 QT5_HAVE_GOBJECT=""
-if test \( "$test_kde5" = "yes" -a "$ENABLE_KDE5" = "TRUE" \) -o \
+if test \( "$test_kf5" = "yes" -a "$ENABLE_KF5" = "TRUE" \) -o \
         \( "$test_qt5" = "yes" -a "$ENABLE_QT5" = "TRUE" \) -o \
         \( "$test_gtk3_kde5" = "yes" -a "$ENABLE_GTK3_KDE5" = "TRUE" \)
 then
@@ -11369,14 +11380,13 @@ AC_SUBST(QT5_GOBJECT_LIBS)
 AC_SUBST(QT5_HAVE_GOBJECT)
 
 dnl ===================================================================
-dnl KDE5 Integration
+dnl KF5 Integration
 dnl ===================================================================
 
 KF5_CFLAGS=""
 KF5_LIBS=""
 KF5_CONFIG="kf5-config"
-if test \( "$test_kde5" = "yes" -a "$ENABLE_KDE5" = "TRUE" \) -o \
-        \( "$test_kf5" = "yes" -a "$ENABLE_KF5" = "TRUE" \) -o \
+if test \( "$test_kf5" = "yes" -a "$ENABLE_KF5" = "TRUE" \) -o \
         \( "$test_gtk3_kde5" = "yes" -a "$ENABLE_GTK3_KDE5" = "TRUE" \)
 then
     if test "$OS" = "HAIKU"; then
diff --git a/cui/source/options/optgdlg.cxx b/cui/source/options/optgdlg.cxx
index 91d3077c15f0..3da20f8b7ffd 100644
--- a/cui/source/options/optgdlg.cxx
+++ b/cui/source/options/optgdlg.cxx
@@ -206,16 +206,6 @@ namespace
 {
 OUString impl_SystemFileOpenServiceName()
 {
-    const OUString &rDesktopEnvironment = Application::GetDesktopEnvironment();
-
-    if ( rDesktopEnvironment.equalsIgnoreAsciiCase("kde5") )
-    {
-        #if ENABLE_KDE5
-        return OUString("com.sun.star.ui.dialogs.KDE5FilePicker" );
-        #else
-        return OUString();
-        #endif
-    }
     #if defined(_WIN32)
     return OUString("com.sun.star.ui.dialogs.SystemFilePicker");
     #elif defined MACOSX
diff --git a/distro-configs/Jenkins/LibreOfficeLinuxUpdater.conf 
b/distro-configs/Jenkins/LibreOfficeLinuxUpdater.conf
index 0ccf7b4f1a14..3e34040ebe55 100644
--- a/distro-configs/Jenkins/LibreOfficeLinuxUpdater.conf
+++ b/distro-configs/Jenkins/LibreOfficeLinuxUpdater.conf
@@ -18,7 +18,7 @@
 --with-external-dict-dir=/usr/share/hunspell
 --enable-dbus
 --enable-extension-integration
-# --enable-kde5
+# --enable-kf5
 --enable-gstreamer-1-0
 --enable-evolution2
 --enable-gio
diff --git a/distro-configs/Jenkins/Linux_dev_master.conf 
b/distro-configs/Jenkins/Linux_dev_master.conf
index 505e03568ad0..0f997e12ff29 100644
--- a/distro-configs/Jenkins/Linux_dev_master.conf
+++ b/distro-configs/Jenkins/Linux_dev_master.conf
@@ -1,4 +1,4 @@
 --enable-dbgutil
---enable-kde5
+--enable-kf5
 CC=/opt/rh/devtoolset-7/root/usr/bin/gcc
 CXX=/opt/rh/devtoolset-7/root/usr/bin/g++
diff --git a/distro-configs/Jenkins/Linux_rel_master.conf 
b/distro-configs/Jenkins/Linux_rel_master.conf
index e98840407052..23b105fbe6b8 100644
--- a/distro-configs/Jenkins/Linux_rel_master.conf
+++ b/distro-configs/Jenkins/Linux_rel_master.conf
@@ -1,3 +1,3 @@
---enable-kde5
+--enable-kf5
 CC=/opt/rh/devtoolset-7/root/usr/bin/gcc
 CXX=/opt/rh/devtoolset-7/root/usr/bin/g++
diff --git a/distro-configs/Jenkins/linux_clang_dbgutil_64 
b/distro-configs/Jenkins/linux_clang_dbgutil_64
index 2feee4326da6..c4f130f6d47e 100644
--- a/distro-configs/Jenkins/linux_clang_dbgutil_64
+++ b/distro-configs/Jenkins/linux_clang_dbgutil_64
@@ -1,4 +1,4 @@
 --enable-dbgutil
 --enable-compiler-plugins
 COMPILER_PLUGINS_CXX=ccache g++ -std=c++11
---enable-kde5
+--enable-kf5
diff --git a/distro-configs/Jenkins/linux_gcc_release_64 
b/distro-configs/Jenkins/linux_gcc_release_64
index e2e56dc802eb..bda437aa57f0 100644
--- a/distro-configs/Jenkins/linux_gcc_release_64
+++ b/distro-configs/Jenkins/linux_gcc_release_64
@@ -1,3 +1,3 @@
 CC=/opt/rh/devtoolset-7/root/usr/bin/gcc
 CXX=/opt/rh/devtoolset-7/root/usr/bin/g++
---enable-kde5
+--enable-kf5
diff --git a/distro-configs/LibreOfficeCoverity.conf 
b/distro-configs/LibreOfficeCoverity.conf
index eee0914ca2f0..e657f937fffe 100644
--- a/distro-configs/LibreOfficeCoverity.conf
+++ b/distro-configs/LibreOfficeCoverity.conf
@@ -13,7 +13,7 @@
 --enable-dbus
 --enable-extension-integration
 --enable-gtk3
---enable-kde5
+--enable-kf5
 --enable-evolution2
 --enable-scripting-beanshell
 --enable-scripting-javascript
diff --git a/distro-configs/LibreOfficeLinux.conf 
b/distro-configs/LibreOfficeLinux.conf
index d4337c4b2dfb..00a70c75010b 100644
--- a/distro-configs/LibreOfficeLinux.conf
+++ b/distro-configs/LibreOfficeLinux.conf
@@ -21,7 +21,7 @@
 --enable-extension-integration
 --enable-odk
 --enable-gtk3-kde5
---enable-kde5
+--enable-kf5
 --enable-gstreamer-1-0
 --enable-evolution2
 --enable-gio
diff --git a/distro-configs/LibreOfficeOnline.conf 
b/distro-configs/LibreOfficeOnline.conf
index ed6de3293432..70b7824164f4 100644
--- a/distro-configs/LibreOfficeOnline.conf
+++ b/distro-configs/LibreOfficeOnline.conf
@@ -11,7 +11,7 @@
 --disable-gtk
 --disable-gtk3
 --disable-qt5
---disable-kde5
+--disable-kf5
 --disable-odk
 --disable-online-update
 --enable-pdfimport
diff --git a/distro-configs/LibreOfficeOpenBSD.conf 
b/distro-configs/LibreOfficeOpenBSD.conf
index 5bcfcaf76621..241b0153b605 100644
--- a/distro-configs/LibreOfficeOpenBSD.conf
+++ b/distro-configs/LibreOfficeOpenBSD.conf
@@ -1,6 +1,6 @@
 --disable-dbus
 --disable-epm
---disable-kde5
+--disable-kf5
 --disable-nss-module
 --disable-odk
 --enable-ext-wiki-publisher
diff --git a/distro-configs/LibreOfficeiOS.conf 
b/distro-configs/LibreOfficeiOS.conf
index 7786120e2279..9a15ad6b083f 100644
--- a/distro-configs/LibreOfficeiOS.conf
+++ b/distro-configs/LibreOfficeiOS.conf
@@ -19,7 +19,7 @@
 --disable-database-connectivity
 --disable-dconf
 --disable-extensions
---disable-kde5
+--disable-kf5
 --disable-odk
 --disable-openssl
 --disable-pdfium
diff --git a/distro-configs/LibreOfficeiOS_Sim.conf 
b/distro-configs/LibreOfficeiOS_Sim.conf
index 146be2bd3bcc..1a4b4dbafea1 100644
--- a/distro-configs/LibreOfficeiOS_Sim.conf
+++ b/distro-configs/LibreOfficeiOS_Sim.conf
@@ -19,7 +19,7 @@
 --disable-database-connectivity
 --disable-dconf
 --disable-extensions
---disable-kde5
+--disable-kf5
 --disable-odk
 --disable-openssl
 --disable-pdfium
diff --git a/include/sal/log-areas.dox b/include/sal/log-areas.dox
index ac391bb3eb81..9666e497856c 100644
--- a/include/sal/log-areas.dox
+++ b/include/sal/log-areas.dox
@@ -479,7 +479,7 @@ certain functionality.
 @li @c vcl.helper
 @li @c vcl.icontest
 @li @c vcl.ios.clipboard
-@li @c vcl.kde5 - KDE5
+@li @c vcl.kf5 - KF5
 @li @c vcl.layout - Widget layout
 @li @c vcl.lazydelete
 @li @c vcl.opengl
diff --git a/postprocess/Rdb_services.mk b/postprocess/Rdb_services.mk
index 0b9e1cfcc9fb..ab2ded7ae3a0 100644
--- a/postprocess/Rdb_services.mk
+++ b/postprocess/Rdb_services.mk
@@ -207,8 +207,8 @@ $(eval $(call gb_Rdb_add_components,services,\
        $(if $(ENABLE_VLC), \
                avmedia/source/vlc/avmediavlc \
        ) \
-       $(if $(ENABLE_KDE5), \
-               shell/source/backends/kde5be/kde5be1 \
+       $(if $(ENABLE_KF5), \
+               shell/source/backends/kf5be/kf5be1 \
        ) \
        $(if $(ENABLE_ONLINE_UPDATE), \
                extensions/source/update/check/updchk.uno \
diff --git a/scp2/InstallScript_setup_osl.mk b/scp2/InstallScript_setup_osl.mk
index 6c2496390883..081f9dc6e26c 100644
--- a/scp2/InstallScript_setup_osl.mk
+++ b/scp2/InstallScript_setup_osl.mk
@@ -35,7 +35,7 @@ $(eval $(call gb_InstallScript_use_modules,setup_osl,\
        $(if $(filter TRUE,$(ENABLE_EVOAB2) $(ENABLE_GIO) $(ENABLE_GTK) 
$(ENABLE_GTK3)),\
                scp2/gnome \
        ) \
-       $(if $(filter TRUE,$(ENABLE_QT5) $(ENABLE_KDE5) $(ENABLE_GTK3_KDE5)),\
+       $(if $(filter TRUE,$(ENABLE_QT5) $(ENABLE_KF5) $(ENABLE_GTK3_KDE5)),\
                scp2/kde \
        ) \
        $(if $(filter TRUE,$(ENABLE_ONLINE_UPDATE)),\
diff --git a/scp2/Module_scp2.mk b/scp2/Module_scp2.mk
index 55ea333df005..33e89172afac 100644
--- a/scp2/Module_scp2.mk
+++ b/scp2/Module_scp2.mk
@@ -39,7 +39,7 @@ $(eval $(call gb_Module_add_targets,scp2,\
        $(if $(filter TRUE,$(ENABLE_EVOAB2) $(ENABLE_GIO) $(ENABLE_GTK) 
$(ENABLE_GTK3)),\
                InstallModule_gnome \
        ) \
-       $(if $(filter TRUE,$(ENABLE_QT5) $(ENABLE_KDE5) $(ENABLE_GTK3_KDE5)),\
+       $(if $(filter TRUE,$(ENABLE_QT5) $(ENABLE_KF5) $(ENABLE_GTK3_KDE5)),\
                InstallModule_kde \
        ) \
 ))
diff --git a/shell/Library_kde5be.mk b/shell/Library_kf5be.mk
similarity index 55%
rename from shell/Library_kde5be.mk
rename to shell/Library_kf5be.mk
index a89892dee17f..628145176e0f 100644
--- a/shell/Library_kde5be.mk
+++ b/shell/Library_kf5be.mk
@@ -7,32 +7,32 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 
-$(eval $(call gb_Library_Library,kde5be1))
+$(eval $(call gb_Library_Library,kf5be1))
 
-$(eval $(call gb_Library_use_sdk_api,kde5be1))
+$(eval $(call gb_Library_use_sdk_api,kf5be1))
 
-$(eval $(call gb_Library_use_externals,kde5be1,\
+$(eval $(call gb_Library_use_externals,kf5be1,\
        boost_headers \
-       kde5 \
+       kf5 \
 ))
 
-$(eval $(call gb_Library_use_libraries,kde5be1,\
+$(eval $(call gb_Library_use_libraries,kf5be1,\
        cppu \
        cppuhelper \
        sal \
 ))
 
-$(eval $(call 
gb_Library_set_componentfile,kde5be1,shell/source/backends/kde5be/kde5be1))
+$(eval $(call 
gb_Library_set_componentfile,kf5be1,shell/source/backends/kf5be/kf5be1))
 
-$(eval $(call gb_Library_add_exception_objects,kde5be1,\
-    shell/source/backends/kde5be/kde5access \
-    shell/source/backends/kde5be/kde5backend \
+$(eval $(call gb_Library_add_exception_objects,kf5be1,\
+    shell/source/backends/kf5be/kf5access \
+    shell/source/backends/kf5be/kf5backend \
 ))
 
 # Workaround for clang+icecream (clang's -frewrite-includes
 # doesn't handle Qt5's QT_HAS_INCLUDE that Qt5 uses for <chrono>).
 ifeq ($(COM_IS_CLANG),TRUE)
-$(eval $(call gb_Library_add_cxxflags,kde5be1, \
+$(eval $(call gb_Library_add_cxxflags,kf5be1, \
     -include chrono \
 ))
 endif
diff --git a/shell/Module_shell.mk b/shell/Module_shell.mk
index a03e020bf4f7..a223aae617e0 100644
--- a/shell/Module_shell.mk
+++ b/shell/Module_shell.mk
@@ -30,9 +30,9 @@ $(eval $(call gb_Module_add_targets,shell,\
 endif
 endif
 
-ifeq ($(ENABLE_KDE5),TRUE)
+ifeq ($(ENABLE_KF5),TRUE)
 $(eval $(call gb_Module_add_targets,shell,\
-       Library_kde5be \
+       Library_kf5be \
 ))
 endif
 
diff --git a/shell/source/backends/desktopbe/desktopbackend.cxx 
b/shell/source/backends/desktopbe/desktopbackend.cxx
index 6b402a892427..2872438d4f96 100644
--- a/shell/source/backends/desktopbe/desktopbackend.cxx
+++ b/shell/source/backends/desktopbe/desktopbackend.cxx
@@ -304,11 +304,9 @@ css::uno::Reference< css::uno::XInterface > createInstance(
 
     // Fall back to the default if the specific backend is not available:
     css::uno::Reference< css::uno::XInterface > backend;
-    if ( desktop == "KDE5" ) {
-        backend = createBackend(
-            context,
-            "com.sun.star.configuration.backend.KDE5Backend");
-    }
+    if (desktop == "PLASMA5")
+        backend = createBackend(context,
+            "com.sun.star.configuration.backend.KF5Backend");
     return backend.is()
         ? backend : static_cast< cppu::OWeakObject * >(new Default);
 }
diff --git a/shell/source/backends/kde5be/kde5access.cxx 
b/shell/source/backends/kf5be/kf5access.cxx
similarity index 99%
rename from shell/source/backends/kde5be/kde5access.cxx
rename to shell/source/backends/kf5be/kf5access.cxx
index 6147c8f0a83d..00db5c5448b4 100644
--- a/shell/source/backends/kde5be/kde5access.cxx
+++ b/shell/source/backends/kf5be/kf5access.cxx
@@ -19,7 +19,7 @@
 
 #include <sal/config.h>
 
-#include "kde5access.hxx"
+#include "kf5access.hxx"
 
 #include <QtGui/QFont>
 #include <QtCore/QString>
@@ -40,7 +40,7 @@
 #include <rtl/string.h>
 #include <rtl/ustring.hxx>
 
-namespace kde5access
+namespace kf5access
 {
 namespace
 {
diff --git a/shell/source/backends/kde5be/kde5access.hxx 
b/shell/source/backends/kf5be/kf5access.hxx
similarity index 89%
rename from shell/source/backends/kde5be/kde5access.hxx
rename to shell/source/backends/kf5be/kf5access.hxx
index e1e8a11c8a94..34ee7c6d3d6b 100644
--- a/shell/source/backends/kde5be/kde5access.hxx
+++ b/shell/source/backends/kf5be/kf5access.hxx
@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#ifndef INCLUDED_SHELL_SOURCE_BACKENDS_KDE5BE_KDE5ACCESS_HXX
-#define INCLUDED_SHELL_SOURCE_BACKENDS_KDE5BE_KDE5ACCESS_HXX
+#ifndef INCLUDED_SHELL_SOURCE_BACKENDS_KF5BE_KF5ACCESS_HXX
+#define INCLUDED_SHELL_SOURCE_BACKENDS_KF5BE_KF5ACCESS_HXX
 
 #include <sal/config.h>
 
@@ -38,7 +38,7 @@ class Any;
 }
 }
 
-namespace kde5access
+namespace kf5access
 {
 css::beans::Optional<css::uno::Any> getValue(OUString const& id);
 }
diff --git a/shell/source/backends/kde5be/kde5backend.cxx 
b/shell/source/backends/kf5be/kf5backend.cxx
similarity index 95%
rename from shell/source/backends/kde5be/kde5backend.cxx
rename to shell/source/backends/kf5be/kf5backend.cxx
index 101a21387a4c..182d24893456 100644
--- a/shell/source/backends/kde5be/kde5backend.cxx
+++ b/shell/source/backends/kf5be/kf5backend.cxx
@@ -52,18 +52,18 @@
 #include <osl/process.h>
 #include <osl/thread.h>
 
-#include "kde5access.hxx"
+#include "kf5access.hxx"
 
 namespace
 {
 OUString getServiceImplementationName()
 {
-    return OUString("com.sun.star.comp.configuration.backend.KDE5Backend");
+    return OUString("com.sun.star.comp.configuration.backend.KF5Backend");
 }
 
 css::uno::Sequence<OUString> getServiceSupportedServiceNames()
 {
-    OUString name("com.sun.star.configuration.backend.KDE5Backend");
+    OUString name("com.sun.star.configuration.backend.KF5Backend");
     return css::uno::Sequence<OUString>(&name, 1);
 }
 
@@ -159,14 +159,14 @@ void readKDESettings(std::map<OUString, 
css::beans::Optional<css::uno::Any>>& rS
 
     for (const OUString& aKey : aKeys)
     {
-        css::beans::Optional<css::uno::Any> aValue = 
kde5access::getValue(aKey);
+        css::beans::Optional<css::uno::Any> aValue = kf5access::getValue(aKey);
         std::pair<OUString, css::beans::Optional<css::uno::Any>> elem
             = std::make_pair(aKey, aValue);
         rSettings.insert(elem);
     }
 }
 
-// init the QApplication when we load the kde5backend into a non-Qt vclplug 
(e.g. Gtk3KDE5)
+// init the QApplication when we load the kf5backend into a non-Qt vclplug 
(e.g. gtk3_kde5)
 // TODO: use a helper process to read these values without linking to Qt 
directly?
 // TODO: share this code somehow with Qt5Instance.cxx?
 void initQApp(std::map<OUString, css::beans::Optional<css::uno::Any>>& 
rSettings)
@@ -212,7 +212,7 @@ Service::Service()
         OUString desktop;
         context->getValueByName("system.desktop-environment") >>= desktop;
 
-        if (desktop == "KDE5")
+        if (desktop == "PLASMA5")
         {
             if (!qApp) // no qt event loop yet
             {
@@ -271,7 +271,7 @@ static cppu::ImplementationEntry const services[]
 }
 
 extern "C" SAL_DLLPUBLIC_EXPORT void*
-kde5be1_component_getFactory(char const* pImplName, void* pServiceManager, 
void* pRegistryKey)
+kf5be1_component_getFactory(char const* pImplName, void* pServiceManager, 
void* pRegistryKey)
 {
     return cppu::component_getFactoryHelper(pImplName, pServiceManager, 
pRegistryKey, services);
 }
diff --git a/shell/source/backends/kde5be/kde5be1.component 
b/shell/source/backends/kf5be/kf5be1.component
similarity index 86%
rename from shell/source/backends/kde5be/kde5be1.component
rename to shell/source/backends/kf5be/kf5be1.component
index 74111874cb6b..ad217dc80e66 100644
--- a/shell/source/backends/kde5be/kde5be1.component
+++ b/shell/source/backends/kf5be/kf5be1.component
@@ -18,8 +18,8 @@
  -->
 
 <component loader="com.sun.star.loader.SharedLibrary" environment="@CPPU_ENV@"
-    prefix="kde5be1" xmlns="http://openoffice.org/2010/uno-components";>
-  <implementation name="com.sun.star.comp.configuration.backend.KDE5Backend">
-    <service name="com.sun.star.configuration.backend.KDE5Backend"/>
+    prefix="kf5be1" xmlns="http://openoffice.org/2010/uno-components";>
+  <implementation name="com.sun.star.comp.configuration.backend.KF5Backend">
+    <service name="com.sun.star.configuration.backend.KF5Backend"/>
   </implementation>
 </component>
diff --git a/svtools/source/uno/fpicker.cxx b/svtools/source/uno/fpicker.cxx
index e367a326e5c7..8ca591e1f692 100644
--- a/svtools/source/uno/fpicker.cxx
+++ b/svtools/source/uno/fpicker.cxx
@@ -39,9 +39,7 @@ static OUString FilePicker_getSystemPickerServiceName()
 {
 #ifdef UNX
     OUString aDesktopEnvironment (Application::GetDesktopEnvironment());
-    if (aDesktopEnvironment.equalsIgnoreAsciiCase("kde5"))
-        return OUString ("com.sun.star.ui.dialogs.KDE5FilePicker");
-    else if (aDesktopEnvironment.equalsIgnoreAsciiCase("macosx"))
+    if (aDesktopEnvironment.equalsIgnoreAsciiCase("macosx"))
         return OUString ("com.sun.star.ui.dialogs.AquaFilePicker");
     else
         return OUString ("com.sun.star.ui.dialogs.SystemFilePicker");
@@ -113,9 +111,7 @@ static OUString FolderPicker_getSystemPickerServiceName()
 {
 #ifdef UNX
     OUString aDesktopEnvironment (Application::GetDesktopEnvironment());
-    if (aDesktopEnvironment.equalsIgnoreAsciiCase("kde5"))
-        return OUString("com.sun.star.ui.dialogs.KDEFolderPicker");
-    else if (aDesktopEnvironment.equalsIgnoreAsciiCase("macosx"))
+    if (aDesktopEnvironment.equalsIgnoreAsciiCase("macosx"))
         return OUString("com.sun.star.ui.dialogs.AquaFolderPicker");
 #endif
     return OUString("com.sun.star.ui.dialogs.SystemFolderPicker");
diff --git a/vcl/CustomTarget_kde5_moc.mk b/vcl/CustomTarget_kf5_moc.mk
similarity index 56%
rename from vcl/CustomTarget_kde5_moc.mk
rename to vcl/CustomTarget_kf5_moc.mk
index 8f9d65c27f31..6247c58161fd 100644
--- a/vcl/CustomTarget_kde5_moc.mk
+++ b/vcl/CustomTarget_kf5_moc.mk
@@ -7,14 +7,14 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 
-$(eval $(call gb_CustomTarget_CustomTarget,vcl/unx/kde5))
+$(eval $(call gb_CustomTarget_CustomTarget,vcl/unx/kf5))
 
-$(call gb_CustomTarget_get_target,vcl/unx/kde5) : \
-       $(call gb_CustomTarget_get_workdir,vcl/unx/kde5)/KDE5FilePicker.moc
+$(call gb_CustomTarget_get_target,vcl/unx/kf5) : \
+       $(call gb_CustomTarget_get_workdir,vcl/unx/kf5)/KF5FilePicker.moc
 
-$(call gb_CustomTarget_get_workdir,vcl/unx/kde5)/%.moc : \
-               $(SRCDIR)/vcl/unx/kde5/%.hxx \
-               | $(call gb_CustomTarget_get_workdir,vcl/unx/kde5)/.dir
+$(call gb_CustomTarget_get_workdir,vcl/unx/kf5)/%.moc : \
+               $(SRCDIR)/vcl/unx/kf5/%.hxx \
+               | $(call gb_CustomTarget_get_workdir,vcl/unx/kf5)/.dir
        $(call gb_Output_announce,$(subst $(WORKDIR)/,,$@),$(true),MOC,1)
        $(MOC5) $< -o $@
 
diff --git a/vcl/Executable_lo_kde5filepicker.mk 
b/vcl/Executable_lo_kde5filepicker.mk
index a34682966778..7d44b3fca120 100644
--- a/vcl/Executable_lo_kde5filepicker.mk
+++ b/vcl/Executable_lo_kde5filepicker.mk
@@ -68,7 +68,7 @@ $(eval $(call gb_Executable_use_libraries,lo_kde5filepicker,\
 $(eval $(call gb_Executable_use_externals,lo_kde5filepicker,\
        boost_headers \
        epoxy \
-       kde5 \
+       kf5 \
        dbus \
 ))
 
diff --git a/vcl/Library_vcl.mk b/vcl/Library_vcl.mk
index 25f11f0cbaea..1c3f0b31eb2d 100644
--- a/vcl/Library_vcl.mk
+++ b/vcl/Library_vcl.mk
@@ -603,7 +603,7 @@ $(eval $(call gb_Library_add_libs,vcl,\
 ))
 
 $(eval $(call gb_Library_add_exception_objects,vcl, \
-    $(if $(or $(ENABLE_QT5),$(ENABLE_KDE5)),vcl/source/app/salplug) \
+    $(if $(or $(ENABLE_QT5),$(ENABLE_KF5)),vcl/source/app/salplug) \
 ))
 
 $(eval $(call gb_Library_use_externals,vcl,\
diff --git a/vcl/Library_vclplug_kde5.mk b/vcl/Library_vclplug_kf5.mk
similarity index 64%
rename from vcl/Library_vclplug_kde5.mk
rename to vcl/Library_vclplug_kf5.mk
index 8b5804185b3e..62dafe2c2536 100644
--- a/vcl/Library_vclplug_kde5.mk
+++ b/vcl/Library_vclplug_kf5.mk
@@ -17,23 +17,23 @@
 #   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 #
 
-$(eval $(call gb_Library_Library,vclplug_kde5))
+$(eval $(call gb_Library_Library,vclplug_kf5))
 
-$(eval $(call gb_Library_use_custom_headers,vclplug_kde5,vcl/unx/kde5))
+$(eval $(call gb_Library_use_custom_headers,vclplug_kf5,vcl/unx/kf5))
 
-$(eval $(call gb_Library_set_include,vclplug_kde5,\
+$(eval $(call gb_Library_set_include,vclplug_kf5,\
     $$(INCLUDE) \
     -I$(SRCDIR)/vcl/inc \
     -I$(SRCDIR)/vcl/inc/qt5 \
 ))
 
-$(eval $(call gb_Library_add_defs,vclplug_kde5,\
-    -DVCLPLUG_KDE5_IMPLEMENTATION \
+$(eval $(call gb_Library_add_defs,vclplug_kf5,\
+    -DVCLPLUG_KF5_IMPLEMENTATION \
 ))
 
-$(eval $(call gb_Library_use_sdk_api,vclplug_kde5))
+$(eval $(call gb_Library_use_sdk_api,vclplug_kf5))
 
-$(eval $(call gb_Library_use_libraries,vclplug_kde5,\
+$(eval $(call gb_Library_use_libraries,vclplug_kf5,\
     vclplug_qt5 \
     vcl \
     tl \
@@ -51,41 +51,41 @@ $(eval $(call gb_Library_use_libraries,vclplug_kde5,\
     sal \
 ))
 
-$(eval $(call gb_Library_use_externals,vclplug_kde5,\
+$(eval $(call gb_Library_use_externals,vclplug_kf5,\
        boost_headers \
        cairo \
        graphite \
        harfbuzz \
        icuuc \
-       kde5 \
+       kf5 \
        epoxy \
 ))
 
 ifneq ($(QT5_HAVE_GLIB),)
-$(eval $(call gb_Library_add_cxxflags,vclplug_kde5,\
+$(eval $(call gb_Library_add_cxxflags,vclplug_kf5,\
     $(QT5_GLIB_CFLAGS) \
 ))
 
-$(eval $(call gb_Library_add_libs,vclplug_kde5,\
+$(eval $(call gb_Library_add_libs,vclplug_kf5,\
     $(QT5_GLIB_LIBS) \
 ))
 endif
 
-$(eval $(call gb_Library_add_cxxflags,vclplug_kde5,\
+$(eval $(call gb_Library_add_cxxflags,vclplug_kf5,\
     $(KF5_CFLAGS) \
 ))
-$(eval $(call gb_Library_add_libs,vclplug_kde5,\
+$(eval $(call gb_Library_add_libs,vclplug_kf5,\
     $(KF5_LIBS) \
 ))
 
-$(eval $(call gb_Library_add_exception_objects,vclplug_kde5,\
-    vcl/unx/kde5/KDE5FilePicker2 \
-    vcl/unx/kde5/KDE5SalFrame \
-    vcl/unx/kde5/KDE5SalInstance \
+$(eval $(call gb_Library_add_exception_objects,vclplug_kf5,\
+    vcl/unx/kf5/KF5FilePicker \
+    vcl/unx/kf5/KF5SalFrame \
+    vcl/unx/kf5/KF5SalInstance \
 ))
 
 ifeq ($(OS),LINUX)
-$(eval $(call gb_Library_add_libs,vclplug_kde5,\
+$(eval $(call gb_Library_add_libs,vclplug_kf5,\
        -lm \
        -ldl \
 ))
@@ -94,7 +94,7 @@ endif
 # Workaround for clang+icecream (clang's -frewrite-includes
 # doesn't handle Qt5's QT_HAS_INCLUDE that Qt5 uses for <chrono>).
 ifeq ($(COM_IS_CLANG),TRUE)
-$(eval $(call gb_Library_add_cxxflags,vclplug_kde5, \
+$(eval $(call gb_Library_add_cxxflags,vclplug_kf5, \
     -include chrono \
 ))
 endif
diff --git a/vcl/Module_vcl.mk b/vcl/Module_vcl.mk
index 78604ab0e9c4..54e3fbd6b07f 100644
--- a/vcl/Module_vcl.mk
+++ b/vcl/Module_vcl.mk
@@ -77,10 +77,10 @@ $(eval $(call gb_Module_add_targets,vcl,\
     Library_vclplug_gtk3 \
 ))
 endif
-ifneq ($(ENABLE_KDE5),)
+ifneq ($(ENABLE_KF5),)
 $(eval $(call gb_Module_add_targets,vcl,\
-    CustomTarget_kde5_moc \
-    Library_vclplug_kde5 \
+    CustomTarget_kf5_moc \
+    Library_vclplug_kf5 \
 ))
 endif
 ifneq ($(ENABLE_QT5),)
@@ -119,10 +119,10 @@ $(eval $(call gb_Module_add_targets,vcl,\
     Library_vclplug_qt5 \
 ))
 endif
-ifneq ($(ENABLE_KDE5),)
+ifneq ($(ENABLE_KF5),)
 $(eval $(call gb_Module_add_targets,vcl,\
-    CustomTarget_kde5_moc \
-    Library_vclplug_kde5 \
+    CustomTarget_kf5_moc \
+    Library_vclplug_kf5 \
 ))
 endif
 endif
diff --git a/vcl/README b/vcl/README
index d8da537939b3..6ee9dad11e80 100644
--- a/vcl/README
+++ b/vcl/README
@@ -38,8 +38,8 @@ unx/
                + GTK2 support
        gtk3/
                + GTK3 support
-       kde5/
-               + KDE5 support
+       kf5/
+               + KF5 support
        gtk3_kde5/
                + GTK3 support with KDE5 file pickers (alternative to native 
kde5 one)
        generic/
diff --git a/vcl/inc/unx/desktops.hxx b/vcl/inc/unx/desktops.hxx
index a4a6700b7e96..531e4c64272b 100644
--- a/vcl/inc/unx/desktops.hxx
+++ b/vcl/inc/unx/desktops.hxx
@@ -31,7 +31,7 @@ enum SAL_DLLPUBLIC_RTTI DesktopType {
     DESKTOP_UNITY,
     DESKTOP_XFCE,
     DESKTOP_MATE,
-    DESKTOP_KDE5,
+    DESKTOP_PLASMA5,
     DESKTOP_LXQT
 }; // keep in sync with desktop_strings[] in salplug.cxx
 
diff --git a/vcl/inc/unx/gendata.hxx b/vcl/inc/unx/gendata.hxx
index 15f201931792..d8f8149ad6a7 100644
--- a/vcl/inc/unx/gendata.hxx
+++ b/vcl/inc/unx/gendata.hxx
@@ -27,7 +27,7 @@ enum GenericUnixSalDataType
 {
     SAL_DATA_GTK,
     SAL_DATA_GTK3,
-    SAL_DATA_KDE5,
+    SAL_DATA_KF5,
     SAL_DATA_UNX,
     SAL_DATA_SVP,
     SAL_DATA_ANDROID,
diff --git a/vcl/inc/vclpluginapi.h b/vcl/inc/vclpluginapi.h
index 495c86b8e57b..589d7244ddaa 100644
--- a/vcl/inc/vclpluginapi.h
+++ b/vcl/inc/vclpluginapi.h
@@ -35,10 +35,10 @@
 #define VCLPLUG_GTK_PUBLIC SAL_DLLPUBLIC_IMPORT
 #endif
 
-#if defined VCLPLUG_KDE5_IMPLEMENTATION
-#define VCLPLUG_KDE5_PUBLIC SAL_DLLPUBLIC_EXPORT
+#if defined VCLPLUG_KF5_IMPLEMENTATION
+#define VCLPLUG_KF5_PUBLIC SAL_DLLPUBLIC_EXPORT
 #else
-#define VCLPLUG_KDE5_PUBLIC SAL_DLLPUBLIC_IMPORT
+#define VCLPLUG_KF5_PUBLIC SAL_DLLPUBLIC_IMPORT
 #endif
 
 #if defined VCLPLUG_OSX_IMPLEMENTATION
diff --git a/vcl/qa/cppunit/app/test_IconThemeSelector.cxx 
b/vcl/qa/cppunit/app/test_IconThemeSelector.cxx
index 5ff3468655cc..cff9641cd033 100644
--- a/vcl/qa/cppunit/app/test_IconThemeSelector.cxx
+++ b/vcl/qa/cppunit/app/test_IconThemeSelector.cxx
@@ -75,8 +75,8 @@ IconThemeSelectorTest::BreezeIsReturnedForKde5Desktop()
 {
     std::vector<vcl::IconThemeInfo> themes = GetFakeInstalledThemes();
     vcl::IconThemeSelector s;
-    OUString r = s.SelectIconThemeForDesktopEnvironment(themes, "kde5");
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("'breeze' theme is returned for kde5 
desktop", OUString("breeze"), r);
+    OUString r = s.SelectIconThemeForDesktopEnvironment(themes, "plasma5");
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("'breeze' theme is returned for Plasma 5 
desktop", OUString("breeze"), r);
 }
 
 void
diff --git a/vcl/source/app/IconThemeSelector.cxx 
b/vcl/source/app/IconThemeSelector.cxx
index 0ed454f2911b..ff2dcc52805a 100644
--- a/vcl/source/app/IconThemeSelector.cxx
+++ b/vcl/source/app/IconThemeSelector.cxx
@@ -55,7 +55,7 @@ IconThemeSelector::GetIconThemeForDesktopEnvironment(const 
OUString& desktopEnvi
     return OUString("colibre");
 #else
     OUString r;
-    if ( desktopEnvironment.equalsIgnoreAsciiCase("kde5") ||
+    if ( desktopEnvironment.equalsIgnoreAsciiCase("plasma5") ||
          desktopEnvironment.equalsIgnoreAsciiCase("lxqt") ) {
         r = "breeze";
     }
diff --git a/vcl/source/app/salplug.cxx b/vcl/source/app/salplug.cxx
index 4ec54849b21c..20604edb7f46 100644
--- a/vcl/source/app/salplug.cxx
+++ b/vcl/source/app/salplug.cxx
@@ -65,11 +65,14 @@ SalInstance* tryInstance( const OUString& rModuleBase, bool 
bForce = false )
 #endif
 
     SalInstance* pInst = nullptr;
+    OUString aUsedModuleBase(rModuleBase);
+    if (aUsedModuleBase == "kde5")
+        aUsedModuleBase = "kf5";
     OUString aModule(
 #ifdef SAL_DLLPREFIX
             SAL_DLLPREFIX
 #endif
-            "vclplug_" + rModuleBase + "lo" SAL_DLLEXTENSION );
+            "vclplug_" + aUsedModuleBase + "lo" SAL_DLLEXTENSION );
 
     osl::Module aMod;
     if (aMod.loadRelative(reinterpret_cast<oslGenericFunction>(&tryInstance), 
aModule, SAL_LOADMODULE_GLOBAL))
@@ -92,7 +95,7 @@ SalInstance* tryInstance( const OUString& rModuleBase, bool 
bForce = false )
                  * So make sure libgtk+ & co are still mapped into memory when
                  * atk-bridge's atexit handler gets called.
                  */
-                if( rModuleBase == "gtk" || rModuleBase == "gtk3" || 
rModuleBase == "gtk3_kde5" || rModuleBase == "win" )
+                if( aUsedModuleBase == "gtk" || aUsedModuleBase == "gtk3" || 
aUsedModuleBase == "gtk3_kde5" || aUsedModuleBase == "win" )
                 {
                     pCloseModule = nullptr;
                 }
@@ -145,8 +148,8 @@ SalInstance* autodetect_plugin()
 {
     static const char* const pKDEFallbackList[] =
     {
-#if ENABLE_KDE5
-        "kde5",
+#if ENABLE_KF5
+        "kf5",
 #endif
 #if ENABLE_GTK3_KDE5
         "gtk3_kde5",
@@ -181,8 +184,7 @@ SalInstance* autodetect_plugin()
               desktop == DESKTOP_XFCE  ||
               desktop == DESKTOP_MATE )
         pList = pStandardFallbackList;
-    else if( desktop == DESKTOP_KDE5 ||
-              desktop == DESKTOP_LXQT )
+    else if (desktop == DESKTOP_PLASMA5 || desktop == DESKTOP_LXQT)
         pList = pKDEFallbackList;
 
     SalInstance* pInst = nullptr;
@@ -257,7 +259,7 @@ SalInstance *CreateSalInstance()
 #ifdef MACOSX
         "osx"
 #else
-        "gtk3", "gtk", "kde5", "gen"
+        "gtk3", "gtk", "kf5", "gen"
 #endif
 #endif
      };
@@ -314,7 +316,7 @@ const OUString& SalGetDesktopEnvironment()
     // Order to match desktops.hxx' DesktopType
     static const char * const desktop_strings[] = {
         "none", "unknown", "GNOME", "UNITY",
-        "XFCE", "MATE", "KDE5", "LXQT" };
+        "XFCE", "MATE", "PLASMA5", "LXQT" };
     static OUString aDesktopEnvironment;
     if( aDesktopEnvironment.isEmpty())
     {
diff --git a/vcl/unx/generic/desktopdetect/desktopdetector.cxx 
b/vcl/unx/generic/desktopdetect/desktopdetector.cxx
index 2c453e051b5c..b2aea898e45c 100644
--- a/vcl/unx/generic/desktopdetect/desktopdetector.cxx
+++ b/vcl/unx/generic/desktopdetect/desktopdetector.cxx
@@ -115,15 +115,11 @@ static bool is_gnome_desktop( Display* pDisplay )
     return ret;
 }
 
-
-static bool is_kde5_desktop()
+static bool is_plasma5_desktop()
 {
-    static const char * pFullVersion = getenv( "KDE_FULL_SESSION" );
-    static const char * pSessionVersion = getenv( "KDE_SESSION_VERSION" );
-    if ( pFullVersion && pSessionVersion && strcmp(pSessionVersion, "5") == 0)
-        return true;
-
-    return false;
+    static const char* pFullVersion = getenv("KDE_FULL_SESSION");
+    static const char* pSessionVersion = getenv("KDE_SESSION_VERSION");
+    return pFullVersion && pSessionVersion && (0 == strcmp(pSessionVersion, 
"5"));
 }
 
 extern "C"
@@ -139,8 +135,8 @@ DESKTOP_DETECTOR_PUBLIC DesktopType 
get_desktop_environment()
 
         if ( aOver.equalsIgnoreAsciiCase( "lxqt" ) )
             return DESKTOP_LXQT;
-        if ( aOver.equalsIgnoreAsciiCase( "kde5" ) )
-            return DESKTOP_KDE5;
+        if (aOver.equalsIgnoreAsciiCase("plasma5") || 
aOver.equalsIgnoreAsciiCase("plasma"))
+            return DESKTOP_PLASMA5;
         if ( aOver.equalsIgnoreAsciiCase( "gnome" ) )
             return DESKTOP_GNOME;
         if ( aOver.equalsIgnoreAsciiCase( "gnome-wayland" ) )
@@ -197,9 +193,8 @@ DESKTOP_DETECTOR_PUBLIC DesktopType 
get_desktop_environment()
     else if ( aDesktopSession.equalsIgnoreAsciiCase( "lxqt" ) )
         return DESKTOP_LXQT;
 
-
-    if ( is_kde5_desktop() )
-        return DESKTOP_KDE5;
+    if (is_plasma5_desktop())
+        return DESKTOP_PLASMA5;
 
     // tdf#121275 if we still can't tell, and WAYLAND_DISPLAY
     // is set, default to gtk3
diff --git a/vcl/unx/gtk3_kde5/kde5_filepicker.cxx 
b/vcl/unx/gtk3_kde5/kde5_filepicker.cxx
index f4cb305e239c..2ee4dbd8e85c 100644
--- a/vcl/unx/gtk3_kde5/kde5_filepicker.cxx
+++ b/vcl/unx/gtk3_kde5/kde5_filepicker.cxx
@@ -68,7 +68,7 @@ void KDE5FilePicker::enableFolderMode()
     // and then confirming would return "foo" rather than "foo/bar";
     // on the other hand, non-native file dialog needs 'QFileDialog::Directory'
     // and doesn't allow folder selection otherwise
-    if (Application::GetDesktopEnvironment() != "KDE5")
+    if (Application::GetDesktopEnvironment() != "PLASMA5")
     {
         _dialog->setFileMode(QFileDialog::Directory);
     }
@@ -248,7 +248,7 @@ void KDE5FilePicker::setupCustomWidgets()
     // dialog there in order not to lose the custom controls and insert the 
custom
     // widget in the layout returned by QFileDialog::layout()
     // (which returns nullptr for native file dialogs)
-    if (Application::GetDesktopEnvironment() == "KDE5")
+    if (Application::GetDesktopEnvironment() == "PLASMA5")
     {
         qApp->installEventFilter(this);
     }
diff --git a/vcl/unx/kde5/KDE5FilePicker.hxx b/vcl/unx/kf5/KF5FilePicker.hxx
similarity index 92%
rename from vcl/unx/kde5/KDE5FilePicker.hxx
rename to vcl/unx/kf5/KF5FilePicker.hxx
index 786a99b00777..6bfc7ee96077 100644
--- a/vcl/unx/kde5/KDE5FilePicker.hxx
+++ b/vcl/unx/kf5/KF5FilePicker.hxx
@@ -23,7 +23,7 @@
 
 class QGridLayout;
 
-class KDE5FilePicker : public Qt5FilePicker
+class KF5FilePicker : public Qt5FilePicker
 {
     Q_OBJECT
 
@@ -34,8 +34,8 @@ protected:
     bool allowRemoteUrls;
 
 public:
-    explicit KDE5FilePicker(css::uno::Reference<css::uno::XComponentContext> 
const& context,
-                            QFileDialog::FileMode);
+    explicit KF5FilePicker(css::uno::Reference<css::uno::XComponentContext> 
const& context,
+                           QFileDialog::FileMode);
 
     // XExecutableDialog functions
     virtual sal_Int16 SAL_CALL execute() override;
diff --git a/vcl/unx/kde5/KDE5SalFrame.cxx b/vcl/unx/kf5/KF5SalFrame.cxx
similarity index 88%
rename from vcl/unx/kde5/KDE5SalFrame.cxx
rename to vcl/unx/kf5/KF5SalFrame.cxx
index efb08a74d832..a212759aeb91 100644
--- a/vcl/unx/kde5/KDE5SalFrame.cxx
+++ b/vcl/unx/kf5/KF5SalFrame.cxx
@@ -28,7 +28,7 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 
-#include "KDE5SalFrame.hxx"
+#include "KF5SalFrame.hxx"
 
 #include <tools/color.hxx>
 
@@ -42,7 +42,7 @@
 
 #include <boost/optional.hpp>
 
-KDE5SalFrame::KDE5SalFrame(KDE5SalFrame* pParent, SalFrameStyleFlags nState, 
bool bUseCairo)
+KF5SalFrame::KF5SalFrame(KF5SalFrame* pParent, SalFrameStyleFlags nState, bool 
bUseCairo)
     : Qt5Frame(pParent, nState, bUseCairo)
     , m_bGraphicsInUse(false)
 {
@@ -101,13 +101,13 @@ static vcl::Font toFont(const QFont& rQFont, const 
css::lang::Locale& rLocale)
     else
         aInfo.m_eWidth = WIDTH_ULTRA_EXPANDED;
 
-    SAL_INFO("vcl.kde5", "font name BEFORE system match: \"" << 
aInfo.m_aFamilyName << "\"");
+    SAL_INFO("vcl.kf5", "font name BEFORE system match: \"" << 
aInfo.m_aFamilyName << "\"");
 
     // match font to e.g. resolve "Sans"
     psp::PrintFontManager::get().matchFont(aInfo, rLocale);
 
-    SAL_INFO("vcl.kde5", "font match " << (aInfo.m_nID != 0 ? "succeeded" : 
"failed")
-                                       << ", name AFTER: \"" << 
aInfo.m_aFamilyName << "\"");
+    SAL_INFO("vcl.kf5", "font match " << (aInfo.m_nID != 0 ? "succeeded" : 
"failed")
+                                      << ", name AFTER: \"" << 
aInfo.m_aFamilyName << "\"");
 
     // font height
     int nPointHeight = qFontInfo.pointSize();
@@ -130,7 +130,7 @@ static vcl::Font toFont(const QFont& rQFont, const 
css::lang::Locale& rLocale)
 
 /** Implementation of KDE integration's main method.
 */
-void KDE5SalFrame::UpdateSettings(AllSettings& rSettings)
+void KF5SalFrame::UpdateSettings(AllSettings& rSettings)
 {
     Qt5Frame::UpdateSettings(rSettings);
 
@@ -196,26 +196,26 @@ void KDE5SalFrame::UpdateSettings(AllSettings& rSettings)
     rSettings.SetStyleSettings(style);
 }
 
-SalGraphics* KDE5SalFrame::AcquireGraphics()
+SalGraphics* KF5SalFrame::AcquireGraphics()
 {
     if (m_bGraphicsInUse)
         return nullptr;
 
     m_bGraphicsInUse = true;
 
-    if (!m_pKDE5Graphics.get())
+    if (!m_pKF5Graphics.get())
     {
-        m_pKDE5Graphics.reset(new Qt5SvpGraphics(this));
-        Qt5Frame::InitQt5SvpGraphics(m_pKDE5Graphics.get());
+        m_pKF5Graphics.reset(new Qt5SvpGraphics(this));
+        Qt5Frame::InitQt5SvpGraphics(m_pKF5Graphics.get());
     }
 
-    return m_pKDE5Graphics.get();
+    return m_pKF5Graphics.get();
 }
 
-void KDE5SalFrame::ReleaseGraphics(SalGraphics* pSalGraph)
+void KF5SalFrame::ReleaseGraphics(SalGraphics* pSalGraph)
 {
     (void)pSalGraph;
-    assert(pSalGraph == m_pKDE5Graphics.get());
+    assert(pSalGraph == m_pKF5Graphics.get());
     m_bGraphicsInUse = false;
 }
 
diff --git a/vcl/unx/kde5/KDE5SalFrame.hxx b/vcl/unx/kf5/KF5SalFrame.hxx
similarity index 89%
rename from vcl/unx/kde5/KDE5SalFrame.hxx
rename to vcl/unx/kf5/KF5SalFrame.hxx
index cf3874af7c8c..091a5b019ca7 100644
--- a/vcl/unx/kde5/KDE5SalFrame.hxx
+++ b/vcl/unx/kf5/KF5SalFrame.hxx
@@ -26,14 +26,14 @@
 
 class QWidget;
 
-class KDE5SalFrame : public Qt5Frame
+class KF5SalFrame : public Qt5Frame
 {
 private:
-    std::unique_ptr<Qt5SvpGraphics> m_pKDE5Graphics;
+    std::unique_ptr<Qt5SvpGraphics> m_pKF5Graphics;
     bool m_bGraphicsInUse;
 
 public:
-    KDE5SalFrame(KDE5SalFrame* pParent, SalFrameStyleFlags nStyle, bool 
bUseCairo);
+    KF5SalFrame(KF5SalFrame* pParent, SalFrameStyleFlags nStyle, bool 
bUseCairo);
 
     virtual SalGraphics* AcquireGraphics() override;
     virtual void ReleaseGraphics(SalGraphics* pGraphics) override;
diff --git a/vcl/unx/kde5/KDE5SalInstance.cxx b/vcl/unx/kf5/KF5SalInstance.cxx
similarity index 71%
rename from vcl/unx/kde5/KDE5SalInstance.cxx
rename to vcl/unx/kf5/KF5SalInstance.cxx
index b1b8eb59375f..da4906a70a49 100644
--- a/vcl/unx/kde5/KDE5SalInstance.cxx
+++ b/vcl/unx/kf5/KF5SalInstance.cxx
@@ -27,39 +27,39 @@
 
 #include <Qt5Data.hxx>
 
-#include "KDE5FilePicker.hxx"
-#include "KDE5SalFrame.hxx"
-#include "KDE5SalInstance.hxx"
+#include "KF5FilePicker.hxx"
+#include "KF5SalFrame.hxx"
+#include "KF5SalInstance.hxx"
 
 using namespace com::sun::star;
 
-KDE5SalInstance::KDE5SalInstance(std::unique_ptr<QApplication>& pQApp)
+KF5SalInstance::KF5SalInstance(std::unique_ptr<QApplication>& pQApp)
     : Qt5Instance(pQApp, true)
 {
     ImplSVData* pSVData = ImplGetSVData();
-    pSVData->maAppData.mxToolkitName = OUString("kde5");
+    pSVData->maAppData.mxToolkitName = OUString("kf5");
 }
 
-SalFrame* KDE5SalInstance::CreateFrame(SalFrame* pParent, SalFrameStyleFlags 
nState)
+SalFrame* KF5SalInstance::CreateFrame(SalFrame* pParent, SalFrameStyleFlags 
nState)
 {
     SalFrame* pRet(nullptr);
     RunInMainThread(std::function([&pRet, pParent, nState]() {
-        pRet = new KDE5SalFrame(static_cast<KDE5SalFrame*>(pParent), nState, 
true);
+        pRet = new KF5SalFrame(static_cast<KF5SalFrame*>(pParent), nState, 
true);
     }));
     assert(pRet);
     return pRet;
 }
 
-bool KDE5SalInstance::hasNativeFileSelection() const
+bool KF5SalInstance::hasNativeFileSelection() const
 {
-    if (Application::GetDesktopEnvironment() == "KDE5")
+    if (Application::GetDesktopEnvironment() == "PLASMA5")
         return true;
     return Qt5Instance::hasNativeFileSelection();
 }
 
 Qt5FilePicker*
-KDE5SalInstance::createPicker(css::uno::Reference<css::uno::XComponentContext> 
const& context,
-                              QFileDialog::FileMode eMode)
+KF5SalInstance::createPicker(css::uno::Reference<css::uno::XComponentContext> 
const& context,
+                             QFileDialog::FileMode eMode)
 {
     if (!IsMainThread())
     {
@@ -70,16 +70,16 @@ 
KDE5SalInstance::createPicker(css::uno::Reference<css::uno::XComponentContext> c
         return pPicker;
     }
 
-    // In order to insert custom controls, KDE5FilePicker currently relies on 
KFileWidget
+    // In order to insert custom controls, KF5FilePicker currently relies on 
KFileWidget
     // being used in the native file picker, which is only the case for KDE 
Plasma.
     // Therefore, return the plain qt5 one in order to not lose custom 
controls.
-    if (Application::GetDesktopEnvironment() == "KDE5")
-        return new KDE5FilePicker(context, eMode);
+    if (Application::GetDesktopEnvironment() == "PLASMA5")
+        return new KF5FilePicker(context, eMode);
     return Qt5Instance::createPicker(context, eMode);
 }
 
 extern "C" {
-VCLPLUG_KDE5_PUBLIC SalInstance* create_SalInstance()
+VCLPLUG_KF5_PUBLIC SalInstance* create_SalInstance()
 {
     std::unique_ptr<char* []> pFakeArgv;
     std::unique_ptr<int> pFakeArgc;
@@ -89,7 +89,7 @@ VCLPLUG_KDE5_PUBLIC SalInstance* create_SalInstance()
     std::unique_ptr<QApplication> pQApp
         = Qt5Instance::CreateQApplication(*pFakeArgc, pFakeArgv.get());
 
-    KDE5SalInstance* pInstance = new KDE5SalInstance(pQApp);
+    KF5SalInstance* pInstance = new KF5SalInstance(pQApp);
     pInstance->MoveFakeCmdlineArgs(pFakeArgv, pFakeArgc, aFakeArgvFreeable);
 
     new Qt5Data(pInstance);
diff --git a/vcl/unx/kde5/KDE5SalInstance.hxx b/vcl/unx/kf5/KF5SalInstance.hxx
similarity index 91%
rename from vcl/unx/kde5/KDE5SalInstance.hxx
rename to vcl/unx/kf5/KF5SalInstance.hxx
index 4215ec483308..5dd306da5231 100644
--- a/vcl/unx/kde5/KDE5SalInstance.hxx
+++ b/vcl/unx/kf5/KF5SalInstance.hxx
@@ -21,7 +21,7 @@
 
 #include <qt5/Qt5Instance.hxx>
 
-class KDE5SalInstance final : public Qt5Instance
+class KF5SalInstance final : public Qt5Instance
 {
     bool hasNativeFileSelection() const override;
     Qt5FilePicker* 
createPicker(css::uno::Reference<css::uno::XComponentContext> const& context,
@@ -30,7 +30,7 @@ class KDE5SalInstance final : public Qt5Instance
     SalFrame* CreateFrame(SalFrame* pParent, SalFrameStyleFlags nStyle) 
override;
 
 public:
-    explicit KDE5SalInstance(std::unique_ptr<QApplication>& pQApp);
+    explicit KF5SalInstance(std::unique_ptr<QApplication>& pQApp);
 };
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/vcl/qt5/Qt5Frame.cxx b/vcl/qt5/Qt5Frame.cxx
index 0bfd51c515da..142cb12aa199 100644
--- a/vcl/qt5/Qt5Frame.cxx
+++ b/vcl/qt5/Qt5Frame.cxx
@@ -1062,14 +1062,14 @@ KeyIndicatorState Qt5Frame::GetIndicatorState() { 
return KeyIndicatorState(); }
 
 void Qt5Frame::SimulateKeyPress(sal_uInt16 nKeyCode)
 {
-    SAL_WARN("vcl.kde5", "missing simulate keypress " << nKeyCode);
+    SAL_WARN("vcl.qt5", "missing simulate keypress " << nKeyCode);
 }
 
 void Qt5Frame::SetParent(SalFrame* pNewParent) { m_pParent = 
static_cast<Qt5Frame*>(pNewParent); }
 
 bool Qt5Frame::SetPluginParent(SystemParentData* /*pNewParent*/)
 {
     //FIXME: no SetPluginParent impl. for kde5
     return false;
 }
 
@@ -1062,14 +1062,14 @@ KeyIndicatorState Qt5Frame::GetIndicatorState() { 
 bool Qt5Frame::SetPluginParent(SystemParentData* /*pNewParent*/)
 {
-    //FIXME: no SetPluginParent impl. for kde5
+    //FIXME: no SetPluginParent impl. for qt5
     return false;
 }
diff --git a/vcl/unx/kde5/KDE5FilePicker2.cxx b/vcl/unx/kf5/KF5FilePicker.cxx
similarity index 80%
rename from vcl/unx/kde5/KDE5FilePicker2.cxx
rename to vcl/unx/kf5/KF5FilePicker.cxx
index cb778e2fd0f7..366ca89ffa54 100644
--- a/vcl/unx/kde5/KDE5FilePicker2.cxx
+++ b/vcl/unx/kf5/KF5FilePicker.cxx
@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "KDE5FilePicker.hxx"
-#include <KDE5FilePicker.moc>
+#include "KF5FilePicker.hxx"
+#include <KF5FilePicker.moc>
 
 #include <com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.hpp>
 #include <cppuhelper/supportsservice.hxx>
@@ -41,17 +41,17 @@ uno::Sequence<OUString> 
FilePicker_getSupportedServiceNames()
     uno::Sequence<OUString> aRet(4);
     aRet[0] = "com.sun.star.ui.dialogs.FilePicker";
     aRet[1] = "com.sun.star.ui.dialogs.SystemFilePicker";
-    aRet[2] = "com.sun.star.ui.dialogs.KDE5FilePicker";
-    aRet[3] = "com.sun.star.ui.dialogs.KDE5FolderPicker";
+    aRet[2] = "com.sun.star.ui.dialogs.KF5FilePicker";
+    aRet[3] = "com.sun.star.ui.dialogs.KF5FolderPicker";
     return aRet;
 }
 }
 
-// KDE5FilePicker
+// KF5FilePicker
 
-KDE5FilePicker::KDE5FilePicker(css::uno::Reference<css::uno::XComponentContext>
 const& context,
-                               QFileDialog::FileMode eMode)
-    // Native kde5 filepicker does not add file extension automatically
+KF5FilePicker::KF5FilePicker(css::uno::Reference<css::uno::XComponentContext> 
const& context,
+                             QFileDialog::FileMode eMode)
+    // Native kf5 filepicker does not add file extension automatically
     : Qt5FilePicker(context, eMode, true, true)
     , _layout(new QGridLayout(m_pExtraControls))
     , allowRemoteUrls(false)
@@ -78,7 +78,7 @@ 
KDE5FilePicker::KDE5FilePicker(css::uno::Reference<css::uno::XComponentContext>
     qApp->installEventFilter(this);
 }
 
-sal_Int16 SAL_CALL KDE5FilePicker::execute()
+sal_Int16 SAL_CALL KF5FilePicker::execute()
 {
     SolarMutexGuard g;
     auto* pSalInst(static_cast<Qt5Instance*>(GetSalData()->m_pInstance));
@@ -101,8 +101,8 @@ sal_Int16 SAL_CALL KDE5FilePicker::execute()
 }
 
 // XFilePickerControlAccess
-void SAL_CALL KDE5FilePicker::setValue(sal_Int16 controlId, sal_Int16 
nControlAction,
-                                       const uno::Any& value)
+void SAL_CALL KF5FilePicker::setValue(sal_Int16 controlId, sal_Int16 
nControlAction,
+                                      const uno::Any& value)
 {
     if (CHECKBOX_AUTOEXTENSION == controlId)
         // We ignore this one and rely on QFileDialog to provide the 
functionality
@@ -111,7 +111,7 @@ void SAL_CALL KDE5FilePicker::setValue(sal_Int16 controlId, 
sal_Int16 nControlAc
     Qt5FilePicker::setValue(controlId, nControlAction, value);
 }
 
-uno::Any SAL_CALL KDE5FilePicker::getValue(sal_Int16 controlId, sal_Int16 
nControlAction)
+uno::Any SAL_CALL KF5FilePicker::getValue(sal_Int16 controlId, sal_Int16 
nControlAction)
 {
     SolarMutexGuard g;
     auto* pSalInst(static_cast<Qt5Instance*>(GetSalData()->m_pInstance));
@@ -136,7 +136,7 @@ uno::Any SAL_CALL KDE5FilePicker::getValue(sal_Int16 
controlId, sal_Int16 nContr
     return Qt5FilePicker::getValue(controlId, nControlAction);
 }
 
-void SAL_CALL KDE5FilePicker::enableControl(sal_Int16 controlId, sal_Bool 
enable)
+void SAL_CALL KF5FilePicker::enableControl(sal_Int16 controlId, sal_Bool 
enable)
 {
     if (CHECKBOX_AUTOEXTENSION == controlId)
         // We ignore this one and rely on QFileDialog to provide the 
functionality
@@ -145,7 +145,7 @@ void SAL_CALL KDE5FilePicker::enableControl(sal_Int16 
controlId, sal_Bool enable
     Qt5FilePicker::enableControl(controlId, enable);
 }
 
-void SAL_CALL KDE5FilePicker::setLabel(sal_Int16 controlId, const OUString& 
label)
+void SAL_CALL KF5FilePicker::setLabel(sal_Int16 controlId, const OUString& 
label)
 {
     if (CHECKBOX_AUTOEXTENSION == controlId)
         // We ignore this one and rely on QFileDialog to provide the 
functionality
@@ -154,7 +154,7 @@ void SAL_CALL KDE5FilePicker::setLabel(sal_Int16 controlId, 
const OUString& labe
     Qt5FilePicker::setLabel(controlId, label);
 }
 
-OUString SAL_CALL KDE5FilePicker::getLabel(sal_Int16 controlId)
+OUString SAL_CALL KF5FilePicker::getLabel(sal_Int16 controlId)
 {
     // We ignore this one and rely on QFileDialog to provide the functionality
     if (CHECKBOX_AUTOEXTENSION == controlId)
@@ -163,9 +163,9 @@ OUString SAL_CALL KDE5FilePicker::getLabel(sal_Int16 
controlId)
     return Qt5FilePicker::getLabel(controlId);
 }
 
-void KDE5FilePicker::addCustomControl(sal_Int16 controlId)
+void KF5FilePicker::addCustomControl(sal_Int16 controlId)
 {
     // native kde5 filepicker has its own autoextension checkbox,
     // therefore avoid adding yet another one
     if (controlId == CHECKBOX_AUTOEXTENSION)
         return;
@@ -174,22 +174,22 @@ void KDE5FilePicker::addCustomControl(sal_Int16 controlId)
 }
 
 // XServiceInfo
-OUString SAL_CALL KDE5FilePicker::getImplementationName()
+OUString SAL_CALL KF5FilePicker::getImplementationName()
 {
-    return OUString("com.sun.star.ui.dialogs.KDE5FilePicker");
+    return OUString("com.sun.star.ui.dialogs.KF5FilePicker");
 }
 
-sal_Bool SAL_CALL KDE5FilePicker::supportsService(const OUString& ServiceName)
+sal_Bool SAL_CALL KF5FilePicker::supportsService(const OUString& ServiceName)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
-uno::Sequence<OUString> SAL_CALL KDE5FilePicker::getSupportedServiceNames()
+uno::Sequence<OUString> SAL_CALL KF5FilePicker::getSupportedServiceNames()
 {
     return FilePicker_getSupportedServiceNames();
 }
 
-bool KDE5FilePicker::eventFilter(QObject* o, QEvent* e)
+bool KF5FilePicker::eventFilter(QObject* o, QEvent* e)
 {
     if (e->type() == QEvent::Show && o->isWidgetType())
     {
@@ -163,9 +163,9 @@ OUString SAL_CALL KDE5FilePicker::getLabel(sal_Int16 
 {
-    // native kde5 filepicker has its own autoextension checkbox,
+    // native kf5 filepicker has its own autoextension checkbox,
     // therefore avoid adding yet another one
     if (controlId == CHECKBOX_AUTOEXTENSION)